#
# spec file for package farstream
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gst_pluginsdir %(pkg-config --variable pluginsdir gstreamer-1.0)
Name:           farstream
Version:        0.2.9+5
Release:        2.6
# License note: the only GPL-2.0+ files are farstream-0.1.1/common/coverage/*
# and common/gstdoc-scangobj; those are just used during the build and do not
# affect the license of the binary packages
Summary:        GStreamer modules and libraries for videoconferencing
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            http://farsight.freedesktop.org/
Source:         %{name}-%{version}.tar.xz
Source1:        baselibs.conf

# PATCH-FEATURE-OPENSUSE farstream-plugin-path.patch fcrozat@suse.com -- Use library policy compliant path for plugin
Patch0:         farstream-plugin-path.patch
# PATCH-FIX-UPSTREAM farstream-glib-non-volatile.patch boo#1185220 dimstar@opensuse.org -- Fix build against GCC11/glib2 without misusing 'volatile'
Patch1:         farstream-glib-non-volatile.patch
# PATCH-FIX-OPENSUSE farstream-drop-examples.patch -- Drop building examples
Patch2:         farstream-drop-examples.patch

BuildRequires:  fdupes
BuildRequires:  glib2-devel >= 2.32
BuildRequires:  gobject-introspection-devel >= 0.10.1
BuildRequires:  gstreamer-devel >= 1.4
BuildRequires:  gtk-doc
#needed by patch0
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.40
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= 1.4
BuildRequires:  pkgconfig(nice) >= 0.1.8

%description
Farstream is a collection of GStreamer modules and libraries for
videoconferencing.

%package -n libfarstream-0_2-5
Summary:        GStreamer modules and libraries for videoconferencing
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       %{name}-data
# While not strictly needed, apps using farstream will need the gstreamer
# plugins, so simply put a Requires here instead of in all apps
Requires:       gstreamer-plugins-farstream

%description -n libfarstream-0_2-5
Farstream is a collection of GStreamer modules and libraries for
videoconferencing.

%package -n typelib-1_0-Farstream-0_2
Summary:        GStreamer modules and libraries for videoconferencing -- Introspection bindings
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n typelib-1_0-Farstream-0_2
Farstream is a collection of GStreamer modules and libraries for
videoconferencing.

This package provides the GObject Introspection bindings for Farstream.

%package -n gstreamer-plugins-farstream
Summary:        GStreamer Plug-Ins for videoconferencing
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
Requires:       gstreamer-plugins-bad >= 1.4
Requires:       gstreamer-plugins-good >= 1.4
# Unfortunately, the gstreamer elements have the same name; since we're
# dropping farsight, let's Obsolete the old package for a smooth transition
Obsoletes:      libgstfarsight-0_10-0

%description -n gstreamer-plugins-farstream
Farstream is a collection of GStreamer modules and libraries for
videoconferencing.

%package data
Summary:        GStreamer modules and libraries for videoconferencing -- Codec preferences
License:        LGPL-2.1-or-later
Group:          System/Libraries
BuildArch:      noarch

%description data
Farstream is a collection of GStreamer modules and libraries for
videoconferencing.

This package contains data (codec preferences, element properties)
used by the library.

%package devel
Summary:        GStreamer modules and libraries for videoconferencing -- Development files
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       libfarstream-0_2-5 = %{version}
Requires:       typelib-1_0-Farstream-0_2 = %{version}

%description devel
Farstream is a collection of GStreamer modules and libraries for
videoconferencing.

%prep
%autosetup -p1

%build
%define _lto_cflags %{nil}
# Needed as we are using a git checkout and patching it.
NOCONFIGURE=1 ./autogen.sh

%configure \
	--disable-static \
	--enable-gtk-doc \
	--enable-introspection \
	--disable-gupnp \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_datadir}/gtk-doc/html/

%post -n libfarstream-0_2-5 -p /sbin/ldconfig
%postun -n libfarstream-0_2-5 -p /sbin/ldconfig

%files -n libfarstream-0_2-5
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/libfarstream-0.2.so.*
%dir %{_libdir}/farstream-0.2-5/
%{_libdir}/farstream-0.2-5/libmulticast-transmitter.so
%{_libdir}/farstream-0.2-5/libnice-transmitter.so
%{_libdir}/farstream-0.2-5/librawudp-transmitter.so
%{_libdir}/farstream-0.2-5/libshm-transmitter.so

%files -n typelib-1_0-Farstream-0_2
%{_libdir}/girepository-1.0/Farstream-0.2.typelib

%files -n gstreamer-plugins-farstream
%{gst_pluginsdir}/libfsrawconference.so
%{gst_pluginsdir}/libfsrtpconference.so
%{gst_pluginsdir}/libfsrtpxdata.so
%{gst_pluginsdir}/libfsvideoanyrate.so

%files data
%dir %{_datadir}/farstream/
%dir %{_datadir}/farstream/0.2/
%dir %{_datadir}/farstream/0.2/fsrawconference/
%{_datadir}/farstream/0.2/fsrawconference/default-element-properties
%dir %{_datadir}/farstream/0.2/fsrtpconference/
%{_datadir}/farstream/0.2/fsrtpconference/default-codec-preferences
%{_datadir}/farstream/0.2/fsrtpconference/default-element-properties

%files devel
%{_includedir}/farstream-0.2/
%{_libdir}/libfarstream-0.2.so
%{_libdir}/pkgconfig/farstream-0.2.pc
%{_datadir}/gir-1.0/Farstream-0.2.gir
%doc %{_datadir}/gtk-doc/html/farstream-libs-0.2/
%doc %{_datadir}/gtk-doc/html/farstream-plugins-0.2/

%changelog
* Mon Aug 29 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Build farstream without gupnp support. Following this, drop
  pkgconfig(gupnp-1.2) and pkgconfig(gupnp-igd-1.0) and pass
  - -disable-gupnp to configure.
* Fri Feb 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.2.9+5:
  + rawudp-upnp test: Also build against new GUPnP 1.2 library if
    present
- Add explicit pkgconfig(gupnp-1.2) BuildRequires and pass
  enable-gupnp to configure, now that upstream supports the version
  we have.
- Add farstream-drop-examples.patch: No longer build the examples.
  Fixes building with gcc 12.
* Wed May 12 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add farstream-glib-non-volatile.patch: Fix build againat GCC11
  with glib no longer misusing 'volatile' (boo#1185220).
* Thu Mar 12 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.2.9+4:
  + nice agent: keep the main context alive until the agent is
    destroyed.
  + configure: add check for glib-mkenums.
  + build: Adapt to backwards incompatible change in GNU Make 4.3.
- Following this, drop upstream fixed patches:
  + farstream-add-check-for-glib-mkenums.patch
  + farstream-fix-make43.patch
* Thu Mar 12 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.2.9:
  + Add OPUS specific SDP OA negotiation to match RFC.
  + Switch VP8 to standard encoding name.
  + Removed MSN plugin, MSN Messenger is long dead.
  + Port away from deprecated libnice signals.
  + Bug fixes.
- Drop farstream-fix-build-gst116.patch: Fixed differently
  upstream.
* Wed Mar  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Switch to git-checkout via source services, commit 092d884d.
- Following the above: Drop autoconf, automake and
  pkgconfig(pygobject-2.0) BuildRequires. Add gtk-doc and libtool.
  Pass autogen.sh inst of autoreconf, and add --enable-gtk-doc and
  - -enable-introspection to configure. Modernize spec.
- Drop farstream-0.2.8-rtpbitrateadapter-no-adaptation.patch: Fixed
  upstream.
- Add farstream-fix-build-gst116.patch: Fix build with gstreamer
  1.16.x  (glfdo#farstream/farstream!3).
- Add farstream-add-check-for-glib-mkenums.patch: Fix autoconf
  build failure for glib-mkenums (glfdo#farstream/farstream!2).
- Add farstream-fix-make43.patch: autotools: Fix build with
  make-4.3 (glfdo#farstream/farstream#17).
- Disable LTO via define, as it currently fails when set to auto.
* Fri Dec  7 2018 fcrozat@suse.com
- Add farstream-0.2.8-rtpbitrateadapter-no-adaptation.patch:
  rtpbitrateadapter should make no adaption by default (bgo#99183).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Mar 12 2016 zaitor@opensuse.org
- Update to version 0.2.8:
  + Add "require-encryption" parameter to ignore unencrypted
    packets.
  + Enable building static GStreamer and transmitter plugins.
  + Make OPUS plugin work and select it as default codec.
  + Bug fixes.
* Wed Apr  1 2015 fcrozat@suse.com
- Add farstream-plugin-path.patch: use library policy compliant
  path name for plugin.
* Thu Jan 29 2015 zaitor@opensuse.org
- Update to version 0.2.7:
  + Add "send-rtcp-mux" parameters to fsrtpsession.
  + Add MTU and buffer splitting to rtpxdatapay.
  + Fix crash if srtpenc/dec is missing.
  + Bug fixes.
- Rename libfarstream-0_2-2 to libfarstream-0_2-5, following
  upstreams soname bump.
* Sun Oct 19 2014 zaitor@opensuse.org
- Update to version 0.2.6:
  + Add ICE-TCP support.
  + Now require libnice 0.1.8.
- Changes from version 0.2.5:
  + Add SRTP support.
  + Add API to set allowed input/output caps.
  + Make it possible to have input that is not a raw format.
  + Support formats with no encoders/decoders.
  + Add payloader for the Microsoft Lync x-data format.
  + Ignore ICE-TCP in new libnice.
  + Fix misc bugs.
  + Now require GStreamer 1.4.
* Mon Sep  8 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf: provide multi-arch packages.
* Fri May  9 2014 zaitor@opensuse.org
- Update to version 0.2.4:
  + Install gtk-doc correctly.
  + Adapt SSRC handling to GStreamer 1.2 and newer.
  + Fix BSD build.
  + Assorted bug fixes.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 0.2.3:
  + Use generic marshallers.
  + Fix building by gold linker.
  + Fix leaks, found by Havard Graff and others.
  + Fix building with automake 1.13.
  + Lower PulseAudio latencies.
  + Fix codec intersection.
  + Add API to make the API be introspection accessible, fixing the
    Python example.
  + Use GSocket and other win32 portability improvements.
* Thu Nov 15 2012 dimstar@opensuse.org
- Update to version 0.2.2:
  + Update and fix the default properties for vp8enc.
* Fri Oct  5 2012 dimstar@opensuse.org
- Update to version 0.2.1:
  + Fix bug where nothing would be sent.
  + Fix various bugs in ElementAddedNotifier.
  + Fix the GPL headers.
  + Misc bug fixes.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 0.2.0:
  + Official GStreamer 1.0 release.
  + Ported python example to GStreamer 1.0 and GTK+ 3.
  + Use GLib 2.32 APIs.
  + Made API more introspection friendly.
  + Ignore Error messages from the decoders.
  + Prefer Opus and VP8.
  + Various bug fixes.
- Rename libfarstream-0_2-1 to libfarstream-0_2-2, following
  upstreams soname bump.
* Fri Sep 14 2012 dimstar@opensuse.org
- Update to version 0.1.91:
  + Minor bug fixes.
  + Bump soname, showing that this version is ABI incompatible.
- Rename libfarstream-0_2-0 to libfarstream-0_2-1, following
  upstreams soname bump
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 0.1.1.99 (0.2.0 git snapshot 2012/09/04)
  + Port to GStreamer 1.0
- Drop farstream-gtkdoc.patch: fixed upstream.
- Drop python sub package: python support has been dropped.
- Rename libfarstream-0_1-0 to libfarstream-0_2-0 and
  typelib-1_0-Farstream-0_1 to typelib-1_0-Fatstream-0_2, following
  upstream library name changes.
* Tue Aug 14 2012 dimstar@opensuse.org
- Add farstream-gtkdoc.patch: Gtk-doc tags belong after the
  description. Fix build on newer gtk-doc versions.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 0.1.2:
  + Ignore config while comparing send codecs, fixes H.264 and
    Theora negotation
  + Require GLib 2.30, do not allow APIs added after and ignore
    later deprecations
  + Add default element properties for rawconference
  + Set better latency/buffer time for pulse src/sink
  + Remove the buffer-time property on the shm transmitter, because
    the gst-plugins-bad plugin has a bug, we will restore it once a
    new gst-plugins-bad version has been released
* Fri Mar 23 2012 vuntz@opensuse.org
- Change libgstfarsight-0_10-0 Conflicts to Obsoletes in
  gstreamer-0_10-plugins-farstream: now that all the farstream
  stack has entered Factory, we can drop the farsight one. The
  Obsoletes will help with a smooth transition.
* Wed Mar 14 2012 vuntz@opensuse.org
- Change license of source package to "GPL-2.0+ and LGPL-2.1+"
  because of the license of some tools from the tarball used during
  the build. This does not affect the license of the binary
  packages. Fix bnc#751720.
* Tue Feb 21 2012 vuntz@opensuse.org
- Initial packaging (version 0.1.1).
